import time
import json
import enlighten


def process_result(result):

    # Get the number of stages and the number of items to build the counter
    nstages = len(result)
    nitems = sum([r['count'] for r in result])

    # Get a stages level progress bar
    manager = enlighten.get_manager()
    stages_bar = manager.counter(total=nitems, desc="Overall Progress:", unit="tasks", color="blue")

    # Iterate over each stage
    for iStage, stage in enumerate(result):

        # Get the number of families (sub-stages) and number of items to build the counter
        nfamilies = len(stage) 
        nfamilyitems = stage['count']
        stage_name = stage['name']
        stage_contents = stage.get('contents', [])

        # Get a family level progress bar
        family_bar = manager.counter(total=nfamilyitems, desc=f"{stage_name} Progress:", unit="tasks", leave=False, color="blue")

        print(f"{stage_name}")

        # Iterate over each family
        for iFamily, family in enumerate(stage_contents):

            # Get the number of controls (sub-sub-stages)
            ncontrols = len(family)
            ncontrolitems = family['count']
            family_name = family['name']
            family_contents = family.get('contents', [])

            # Set leave to False since this will be replaced when done
            control_bar = manager.counter(total=ncontrolitems, desc=f"{family_name} Progress:", unit="tasks", leave=False, color="blue")

            print(f"{family_name}")

            # Iterate over each control
            for iControl, control in enumerate(family_contents):

                control_name = control['name']
                print(f"{control_name}")

                for i in range(control['count']):
                    control_bar.update()
                    frac = (i+1)/control['count']
                    time.sleep(frac*control['time'])

                    # Update count
                    family_bar.update()
                    stages_bar.update()

            # Close this counter so it gets removed
            control_bar.close()

        # Close the counter so it gets removed
        family_bar.close()

    # Can check here for time key and wait that long,
    # in case there is no family subitem -
    # can still use a stage by itself as a step
    
    # Closing this counter does not remove it, but it does a refresh
    stages_bar.close()


def main():
    with open('result.json', 'r') as f:
        result = json.load(f)
    process_result(result) 


if __name__=="__main__":
    main()
